pub fn format_sections(analysis: &ElfAnalysis, bar_width: usize) -> StringExpand description
Format a per-section breakdown table.
Shows each allocated section with its name, region type, size, percentage of region, and a small progress bar.
pub fn format_sections(analysis: &ElfAnalysis, bar_width: usize) -> StringFormat a per-section breakdown table.
Shows each allocated section with its name, region type, size, percentage of region, and a small progress bar.